==> zio-aws-securityhub_2.13-5.17.164.1-sources.jar: zio/aws/securityhub/model/StringFilterComparison.scala <==
package zio.aws.securityhub.model
import scala.jdk.CollectionConverters._
sealed trait StringFilterComparison {
  def unwrap
      : software.amazon.awssdk.services.securityhub.model.StringFilterComparison
}
object StringFilterComparison {
  def wrap(
      value: software.amazon.awssdk.services.securityhub.model.StringFilterComparison
  ): zio.aws.securityhub.model.StringFilterComparison = value match {
    case software.amazon.awssdk.services.securityhub.model.StringFilterComparison.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.securityhub.model.StringFilterComparison.EQUALS =>
      val r = EQUALS
      r
    case software.amazon.awssdk.services.securityhub.model.StringFilterComparison.PREFIX =>
      val r = PREFIX
      r
    case software.amazon.awssdk.services.securityhub.model.StringFilterComparison.NOT_EQUALS =>
      val r = NOT_EQUALS
      r
    case software.amazon.awssdk.services.securityhub.model.StringFilterComparison.PREFIX_NOT_EQUALS =>
      val r = PREFIX_NOT_EQUALS
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.securityhub.model.StringFilterComparison {
    override def unwrap
        : software.amazon.awssdk.services.securityhub.model.StringFilterComparison =
      software.amazon.awssdk.services.securityhub.model.StringFilterComparison.UNKNOWN_TO_SDK_VERSION
  }
  case object EQUALS extends zio.aws.securityhub.model.StringFilterComparison {
    override def unwrap
        : software.amazon.awssdk.services.securityhub.model.StringFilterComparison =
      software.amazon.awssdk.services.securityhub.model.StringFilterComparison.EQUALS
  }
  case object PREFIX extends zio.aws.securityhub.model.StringFilterComparison {
    override def unwrap
        : software.amazon.awssdk.services.securityhub.model.StringFilterComparison =
      software.amazon.awssdk.services.securityhub.model.StringFilterComparison.PREFIX
  }
  case object NOT_EQUALS
      extends zio.aws.securityhub.model.StringFilterComparison {
    override def unwrap
        : software.amazon.awssdk.services.securityhub.model.StringFilterComparison =
      software.amazon.awssdk.services.securityhub.model.StringFilterComparison.NOT_EQUALS
  }
  case object PREFIX_NOT_EQUALS
      extends zio.aws.securityhub.model.StringFilterComparison {
    override def unwrap
        : software.amazon.awssdk.services.securityhub.model.StringFilterComparison =
      software.amazon.awssdk.services.securityhub.model.StringFilterComparison.PREFIX_NOT_EQUALS
  }
}

==> zio-aws-securityhub_2.13-6.20.162.1-sources.jar: zio/aws/securityhub/model/StringFilterComparison.scala <==
package zio.aws.securityhub.model
import scala.jdk.CollectionConverters._
sealed trait StringFilterComparison {
  def unwrap
      : software.amazon.awssdk.services.securityhub.model.StringFilterComparison
}
object StringFilterComparison {
  def wrap(
      value: software.amazon.awssdk.services.securityhub.model.StringFilterComparison
  ): zio.aws.securityhub.model.StringFilterComparison = value match {
    case software.amazon.awssdk.services.securityhub.model.StringFilterComparison.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.securityhub.model.StringFilterComparison.EQUALS =>
      val r = EQUALS
      r
    case software.amazon.awssdk.services.securityhub.model.StringFilterComparison.PREFIX =>
      val r = PREFIX
      r
    case software.amazon.awssdk.services.securityhub.model.StringFilterComparison.NOT_EQUALS =>
      val r = NOT_EQUALS
      r
    case software.amazon.awssdk.services.securityhub.model.StringFilterComparison.PREFIX_NOT_EQUALS =>
      val r = PREFIX_NOT_EQUALS
      r
    case software.amazon.awssdk.services.securityhub.model.StringFilterComparison.CONTAINS =>
      val r = CONTAINS
      r
    case software.amazon.awssdk.services.securityhub.model.StringFilterComparison.NOT_CONTAINS =>
      val r = NOT_CONTAINS
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.securityhub.model.StringFilterComparison {
    override def unwrap
        : software.amazon.awssdk.services.securityhub.model.StringFilterComparison =
      software.amazon.awssdk.services.securityhub.model.StringFilterComparison.UNKNOWN_TO_SDK_VERSION
  }
  case object EQUALS extends zio.aws.securityhub.model.StringFilterComparison {
    override def unwrap
        : software.amazon.awssdk.services.securityhub.model.StringFilterComparison =
      software.amazon.awssdk.services.securityhub.model.StringFilterComparison.EQUALS
  }
  case object PREFIX extends zio.aws.securityhub.model.StringFilterComparison {
    override def unwrap
        : software.amazon.awssdk.services.securityhub.model.StringFilterComparison =
      software.amazon.awssdk.services.securityhub.model.StringFilterComparison.PREFIX
  }
  case object NOT_EQUALS
      extends zio.aws.securityhub.model.StringFilterComparison {
    override def unwrap
        : software.amazon.awssdk.services.securityhub.model.StringFilterComparison =
      software.amazon.awssdk.services.securityhub.model.StringFilterComparison.NOT_EQUALS
  }
  case object PREFIX_NOT_EQUALS
      extends zio.aws.securityhub.model.StringFilterComparison {
    override def unwrap
        : software.amazon.awssdk.services.securityhub.model.StringFilterComparison =
      software.amazon.awssdk.services.securityhub.model.StringFilterComparison.PREFIX_NOT_EQUALS
  }
  case object CONTAINS
      extends zio.aws.securityhub.model.StringFilterComparison {
    override def unwrap
        : software.amazon.awssdk.services.securityhub.model.StringFilterComparison =
      software.amazon.awssdk.services.securityhub.model.StringFilterComparison.CONTAINS
  }
  case object NOT_CONTAINS
      extends zio.aws.securityhub.model.StringFilterComparison {
    override def unwrap
        : software.amazon.awssdk.services.securityhub.model.StringFilterComparison =
      software.amazon.awssdk.services.securityhub.model.StringFilterComparison.NOT_CONTAINS
  }
}
